//=========================================================================
//
//	FILE:				DragDrop_ContentsView.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_ScrollableView to display the contents of a CP_DragDrop operation.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2005-08-30 22:32:52 -0700 (Tue, 30 Aug 2005) $
//
//=========================================================================
#ifndef _H_DragDropContentsView
#define _H_DragDropContentsView
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_DataStream.h"
#include "CP_ScrollableView.h"

	/// Standard Library
#include <vector>

#ifndef TARGET_OS_LINUX
	typedef std::vector<CPLAT::CP_DataStream, std::allocator<CPLAT::CP_DataStream> >				CP_DroppedItems;
	typedef std::vector<CPLAT::CP_DataStream, std::allocator<CPLAT::CP_DataStream> >::iterator		CP_DroppedItems_Iterator;
#else
	typedef std::vector<CPLAT::CP_DataStream>														CP_DroppedItems;
	typedef std::vector<CPLAT::CP_DataStream>::iterator												CP_DroppedItems_Iterator;
#endif

/*!
*	\class		DragDropContentsView
*	\brief		CP_ScrollableView to display the contents of a CP_DragDrop operation.
*/
class CP_EXPORT DragDropContentsView : public CPLAT::CP_ScrollableView
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										DragDropContentsView(
												CPLAT::CP_View *inSuperview,
												const CPLAT::CP_Point& inUpperLeft,
												const CPLAT::CP_Size& inContentSize );
	//! Destructor.
	virtual								~DragDropContentsView() throw();
	//@}
			
	//! @name Drag and Drop
	//@{
	virtual	bool						OnCanAcceptDrag(
												UInt32 inItem,
												CPLAT::CP_DragDrop& inDragDrop );
	virtual	void						HandleDragReceive( CPLAT::CP_DragDrop& inDragDrop );
	//@}

protected:
	//! @name AboutBox
	//@{
	virtual	void						OnDraw(
												CPLAT::CP_Canvas& inCanvas,
												CPLAT::CP_Region& inUpdateArea );
	//@}

	//! @name Events
	//@{
	virtual	void						InitEventHandler( CPLAT::CP_EventHandler& inEventHandler );

			void 						HandleDroppedFilesEvent( CPLAT::CP_Event_Base& inEvent );
	//@}

	// class data
protected:
	CP_DroppedItems						fDroppedItems;	/* ! List of items dropped onto this view. */
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

#endif	// _H_DragDropContentsView

