//=========================================================================
//
//	FILE:				CP_ViewContent_TV_DB_Doc.cpp
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_Document class to show the CP_TV_DataBrower in a
//						simple single column tree view.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 6 $
//						Latest Checkout:  $Date: 2005-09-05 19:25:45 -0700 (Mon, 05 Sep 2005) $
//
//=========================================================================

	// Document
#include "CP_ViewContent_TV_DB_Doc.h"

	// CPLAT_Framework
#include "CP_Alerts.h"
#include "CP_Debugging.h"
#include "CP_Document.Tmpl.h"
#include "CP_DocumentWindow.h"
#include "CP_New.h"
#include "CP_MenuBarManager.h"
#include "CP_OSStatus.h"
#include "CP_Scroller.h"
#include "CP_Structure_Defines.h"
#include "CP_TV_DataBrowser.h"
#include "CP_TV_DataBrowserHandlers.h"
#include "CP_TV_DataBrowserRow.h"
#include "CP_TV_DataBrowser_Defines.h"
#include "CP_Types.h"
#include "CP_utility.h"
#include "CP_Window.h"
#include "CP_WindowManager.h"

const UInt16 kNumberRows = 50;
const UInt16 kNumberChildRows = 5;
const UInt16 kNumberColumns = 1;

const UInt32 kCommandBase = 1000;

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Construction / Destruction ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	CP_ViewContent_TV_DataBrowser_Doc
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*
*	@param		inContainer			The scriptable object that serves as a container
*									for this document. In this case it will be the
*									application object.
*	@param		inDocType			The documents default file type.
*	
*	@exception	none
*/
CP_ViewContent_TV_DataBrowser_Doc::CP_ViewContent_TV_DataBrowser_Doc( CPLAT::CP_ScriptableObject *inContainer, CPLAT::FourCharCode inDocType )
	: inherited( inContainer, inDocType ), fViewContentDataSource(NULL)
{
	fViewContentDataSource = CP_new CP_ViewContentDataSource;
}

//=========================================================================
//	FUNCTION:	~CP_ViewContent_TV_DataBrowser_Doc
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*
*	@exception	none
*/
CP_ViewContent_TV_DataBrowser_Doc::~CP_ViewContent_TV_DataBrowser_Doc() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Creation ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	DocumentCreator
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Called when some action has requested we create a new document object. This
*	is usually called from the CP_DocumentFactoryManager when it needs to create
*	a new document.
*
*	@param		inContainer			The scriptable object that serves as a container
*									for this document. In this case it will be the
*									application object.
*	@param		inDocumentClass		The documents default file type.
*	
*	@exception	none
*
*	@return		void
*/
CPLAT::CP_Document_Base *CP_ViewContent_TV_DataBrowser_Doc::DocumentCreator( CPLAT::CP_ScriptableObject *inContainer,
	CPLAT::FourCharCode inDocumentClass )
{
	return( CP_new CP_ViewContent_TV_DataBrowser_Doc( inContainer, inDocumentClass ) );
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Main Window ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleCreateDocumentUI
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Called when the document wants to create the main user interface for the
*	document. In this demo we create a window, with a CP_TextView in it.
*	
*	@exception	none
*
*	@return		void
*/
void CP_ViewContent_TV_DataBrowser_Doc::HandleCreateDocumentUI( SInt32 inPostCreateFlags )
{
	try
	{
		CPLAT::CP_DocumentWindow		*window = NULL;
		CPLAT::CP_Point					windowLocation( 10, 50 );
		CPLAT::CP_Size					windowSize( 400, 300 );
		CPLAT::CP_String				windowTitle( "View Content CP_TV_DataBrowser" );
		CPLAT::CP_DocumentWindowType	documentWindowType;
		CPLAT::CP_Scroller				*tableScroller = NULL;
		
		window = CP_new CPLAT::CP_DocumentWindow();
		window->Create( windowLocation, windowSize, windowTitle, documentWindowType );

		CPLAT::CP_MenuBarManager::Instance()->GetCurrentMenuBar()->SetMainWindow( window );

		CPLAT::CP_Point					viewLocation( 0, 0 );
		CPLAT::CP_Size					viewSize( 0, 0 );
		SInt32							counter = 1;
		SInt32							childRowCounter = 1;
		SInt32							colCounter = 1;
		CPLAT::CP_Size					scrollUnit( 20, 20 );
		CPLAT::CP_S_TV_DB_Properties	viewContentDataBrowserProperties;
		CPLAT::CP_TV_DataBrowser		*viewContentDataBrowser = NULL;
		UInt32							nextID = 1;
		CPLAT::CP_TV_DataBrowserRow		*nextRow = NULL;
		CPLAT::CP_TV_DataBrowserRow		*childRow = NULL;
		UInt32							rowID = 1;
		
		viewLocation.Set( 0, 0 );
		viewSize.Set( 400, 300 );
		tableScroller = CP_new CPLAT::CP_Scroller( window, viewLocation, viewSize );
		tableScroller->SetFrameAdapter( CP_new CPLAT::CP_FrameAdapter_Sticky() );
		
		viewLocation.Set( 0, 0 );
		viewSize.Set( 400 - 16, 300 - 16 );
		viewContentDataBrowserProperties.fNumberColumns = 1;
		viewContentDataBrowser = CP_new CPLAT::CP_TV_DataBrowser( tableScroller, viewLocation, viewSize, viewContentDataBrowserProperties );
		viewContentDataBrowser->SetDataSource( fViewContentDataSource );
		
		tableScroller->SetScrollingView( viewContentDataBrowser );
		viewContentDataBrowser->SetScrollUnit( scrollUnit );

			// set up the tables content handlers
		CPLAT::CP_TV_DataBrowser_CH_View			*viewContentHanler = CP_new CPLAT::CP_TV_DataBrowser_CH_View;
		CPLAT::CP_S_TV_DB_ContentHandlerInfo		viewContentContentHandlerInfo( CPLAT::kCP_Content_View, viewContentHanler );
		viewContentDataBrowser->RegisterHandler( viewContentContentHandlerInfo );
		viewContentHanler->FindSignal( kCP_Signal_HelperViewCreated )->connect( CPLAT::CP_SigSlot::slot(this, &CP_ViewContent_TV_DataBrowser_Doc::HandleHelperViewCreated) );

		viewContentDataBrowser->SetColumnContentType( 1, CPLAT::kCP_Content_View );

		viewContentDataBrowser->SetColumnWidth( -1, 1, 250 );
		viewContentDataBrowser->SetRowHeight( -1, 25 );
		
			// now add the data to the table view
		for( counter = 1; counter <= kNumberRows; counter++ )
		{
			nextRow = CP_new CPLAT::CP_TV_DataBrowserRow( viewContentDataBrowser, rowID );
			viewContentDataBrowser->AddRootRow( nextRow );
			rowID++;
			
				// set the cells data identifier for each cell in this row
			for( colCounter = 1; colCounter <= 1; colCounter++ )
			{
				CPLAT::CP_S_TV_DB_CellData			cellData = nextRow->GetCellData( colCounter );
				cellData.fCellID = nextID;
				nextRow->SetCellData( colCounter, cellData );
				
				nextID++;
			}

				// add the rows to the row created above as child rows
			for( childRowCounter = 1; childRowCounter <= kNumberChildRows; childRowCounter++ )
			{
				childRow = CP_new CPLAT::CP_TV_DataBrowserRow( viewContentDataBrowser, rowID );
				nextRow->AddChild( childRow );
				rowID++;
				
					// set the cells data identifier for each cell in this row
				for( colCounter = 1; colCounter <= 1; colCounter++ )
				{
					CPLAT::CP_S_TV_DB_CellData			cellData = nextRow->GetCellData( colCounter );
					cellData.fCellID = nextID;
					childRow->SetCellData( colCounter, cellData );
					
					nextID++;
				}
			}
		}

			// associate our main window as the documents main window.
		SetMainWindow( window );
		
		CPLAT::CP_WindowManager::Instance()->Reposition( window, NULL, CPLAT::kCP_E_WindowPos_WindowCascadeOnMainScreen );

		window->Show();
	}
	catch(...)
	{
	}
}

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Signal / Slots ==
#pragma mark -
#endif

//=========================================================================
//	FUNCTION:	HandleHelperViewCreated
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Slot called when the TV_DataBrowser has created a helper view. These are
*	the views like edit fields, check boxes, popup menus, etc that implement
*	display of data by using another CP_View object.
*
*	@param		inValue					CP_S_TV_DB_ParamBlock containing data
*										from the data browser view.
*	@param		inOutStatus				Not used.
*	
*	@exception	none
*
*	@return		void
*/
void CP_ViewContent_TV_DataBrowser_Doc::HandleHelperViewCreated( CPLAT::CP_DataValueHolder& inValue,
	CPLAT::OSStatus& /*inOutStatus*/ )
{
	CPLAT::CP_S_TV_DB_ParamBlock		paramBlock;
	
	inValue.Get( paramBlock );
	
	switch( paramBlock.fCellID )
	{
		case 2:
		case 3:
		case 6:
			CPLAT::CP_Object::Connect( paramBlock.fHelperView, kCP_Signal_Clicked, &CP_ViewContent_TV_DataBrowser_Doc::ControlClicked );
			break;

		case 5:
			{
				UInt16									itemCounter = 0;
				
				for( itemCounter = 0; itemCounter < 5; itemCounter++ )
					Connect( 2000 + itemCounter, &CP_ViewContent_TV_DataBrowser_Doc::HandlePopupCommand, CPLAT::CP_Command::CP_E_CH_AlwaysEnable );
			}
			break;
	}
}

//=========================================================================
//	FUNCTION:	HandlePopupCommand
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Slot called when a menu command from a popup menu is issued.
*
*	@param		inOutStatus				Not used.
*	@param		inCommandNo				Not used.
*	
*	@exception	none
*
*	@return		void
*/
void CP_ViewContent_TV_DataBrowser_Doc::HandlePopupCommand( CPLAT::OSStatus& /*inOutStatus*/,
	CPLAT::CP_CommandNo& inCommandNo )
{
	CPLAT::CP_String				alertMessage( "Popup menu selected: " );
	CPLAT::CP_String				alertDescription = CPLAT::CP_Utility::CP_SInt32ToString( inCommandNo );

	CPLAT::CP_Alerts::CP_OSAlert::ShowAlert( alertMessage, alertDescription );
}

//=========================================================================
//	FUNCTION:	ControlClicked
//	
//	VISIBLITY:	Private
//=========================================================================
/*!
*	Generic slot that gets called when controls are clicked. This will post an
*	alert that displies the value of the control, along with the command that
*	the sending control used when calling this slot.
*
*	@return		inValue				Holds a CP_S_ControlClickedInfo structure that
*									describes information about the sending control
*									and value from the control that was clicked.
*	@return		inOutStatus			Not used.
*	
*	@exception	none
*
*	@return		void
*/
void CP_ViewContent_TV_DataBrowser_Doc::ControlClicked( CPLAT::CP_DataValueHolder& inValue,
	CPLAT::OSStatus& /*inOutStatus*/ )
{
	CPLAT::CP_String					description("Value: ");
	CPLAT::CP_S_ControlClickedInfo		clickedInfo;
	
	inValue.Get(clickedInfo);
		
	description += CPLAT::CP_Utility::CP_SInt32ToString( clickedInfo.fValue );
	description += "  Command: ";
	description += CPLAT::CP_Utility::CP_UInt32ToString( clickedInfo.fCommand );

		// display result to user
	CPLAT::CP_String					itemClicked;
	char								viewNameBuffer[ 1024 ];
	const char							*viewName = &viewNameBuffer[0];
	
	if( clickedInfo.fSendingControl != NULL )
	{
		CP_STD::sprintf( viewNameBuffer, "%s", typeid(*clickedInfo.fSendingControl).name() );
		itemClicked += viewName;
	}
		
	itemClicked += " clicked";
	
	CPLAT::CP_Alerts::CP_OSAlert::ShowAlert( itemClicked, description );
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark === Construction / Destruction ==
#endif

//=========================================================================
//	FUNCTION:	CP_ViewContentDataSource
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Constructor.
*	
*	@exception	none
*/
CP_ViewContentDataSource::CP_ViewContentDataSource()
	: CP_DataSource()
{
}

//=========================================================================
//	FUNCTION:	~CP_ViewContentDataSource
//	
//	VISIBLITY:	Public
//=========================================================================
/*!
*	Destructor.
*	
*	@exception	none
*/
CP_ViewContentDataSource::~CP_ViewContentDataSource() throw()
{
}

#if TARGET_CC_METROWERKS
#pragma mark === Notification ==
#endif

//=========================================================================
//	FUNCTION:	GetData
//	
//	VISIBLITY:	Protected
//=========================================================================
/*!
*	CP_DataSource method called to get data for the passed in identifier.
*
*	@return		inID					The identifier of the data to be retrieved.
*	
*	@exception	none
*
*	@return		void
*/
CPLAT::CP_DataValueHolder CP_ViewContentDataSource::GetData( SInt32 inID )
{
	CPLAT::CP_S_TV_DB_DataSourceView		viewData;
	
	switch( inID )
	{
		case 2:
			{
				viewData.fViewType = CPLAT::kCP_TV_DB_ViewType_PushButton;
				viewData.fMinimum = 0;
				viewData.fMaximum = 2;
				viewData.fValue = 0;
				viewData.fHelperViewInsets.Set( 12, 5, 12, 5 );
				viewData.fTitle = "Push Button";
				viewData.fCommand = kCommandBase + inID;
			}
			break;
			
		case 3:
			{
				viewData.fViewType = CPLAT::kCP_TV_DB_ViewType_CheckBox;
				viewData.fTitle = "A check box";
				viewData.fValue = 1;
				viewData.fCommand = kCommandBase + inID;
			}
			break;

		case 4:
			{
				viewData.fViewType = CPLAT::kCP_TV_DB_ViewType_Slider;
				viewData.fMinimum = 0;
				viewData.fMaximum = 100;
				viewData.fValue = 50;
			}
			break;

		case 5:
			{
				viewData.fViewType = CPLAT::kCP_TV_DB_ViewType_Popup;
				viewData.fMinimum = 1000;
				viewData.fTitle = "Popup";
			}
			break;

		case 7:
			{
				viewData.fViewType = CPLAT::kCP_TV_DB_ViewType_RadioButton;
				viewData.fTitle = "A radio button";
				viewData.fValue = 1;
				viewData.fCommand = kCommandBase + inID;
			}
			break;

		default:
			{
				viewData.fViewType = CPLAT::kCP_TV_DB_ViewType_Progress;
				viewData.fMinimum = 0;
				viewData.fMaximum = 100;
				viewData.fValue = 5;
				viewData.fHelperViewInsets.Set( 0, 2, 0, 2 );
			}
			break;
	}
	
	CPLAT::CP_DataValueHolder		returnData = CPLAT::CP_DataValueHolder( viewData );
	
	return( returnData );
}

#if TARGET_OS_MAC

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Mac Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_MAC

#if TARGET_OS_WIN32

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Win Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_WIN32

#if TARGET_OS_LINUX

#if TARGET_CC_METROWERKS
#pragma mark -
#pragma mark === Linux Specific ===
#pragma mark -
#endif

#endif	// TARGET_OS_LINUX
