//=========================================================================
//
//	FILE:				Threads_App.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Application class for the Threads demo.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 5 $
//						Latest Checkout:  $Date: 2005-08-30 20:33:54 -0700 (Tue, 30 Aug 2005) $
//
//=========================================================================
#ifndef _H_Threads_Application
#define _H_Threads_Application
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Application.h"
#include "CP_DocumentPolicy_Multi.h"
#include "CP_OSStatus.h"
#include "CP_PrintPolicy_None.h"
#include "CP_SmartPtr.h"
#include "CP_Types.h"
#include "CP_UndoPolicy_None.h"

/*!
*	@class		CP_Threads_Application
*	@brief		Application class for the threads demo.
*/
class CP_Threads_Application : public CPLAT::CP_Application<CPLAT::CP_DocumentPolicy_Multi,
		CPLAT::CP_PrintPolicy_None, CPLAT::CP_UndoPolicy_None>
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Threads_Application();
	//! Destructor.
	virtual								~CP_Threads_Application() throw();
	//@}
			
protected:
	//! @name AboutBox
	//@{
	virtual	CPLAT::CP_String			GetAboutBoxDescription() const;
	//@}

	//! @name Commands
	//@{
	virtual	void						HandleOpenApplication();

										/*!
										*	Handles the menu/command update status handler for the CP_CMD_New command. We
										*	always enable the command, so many windows can be created if desired.
										*	
										*	@param		inOutCommandStatuss		Loccation to return the enabled status result in.
										*	@param		inOutWasHandled			Not used.
										*	@param		inCommandNo				Not used.
										*
										*	@exception	none
										*	
										*	@return		void
										*/
	virtual	void						HandleNewUpdateCommandStatusCommand(
												CPLAT::CP_CommandStatus& inOutCommandStatus,
												bool& /*inOutWasHandled*/,
												CPLAT::CP_CommandNo& /*inCommandNo*/ )					{ inOutCommandStatus.SetIsEnabled( true ); }
	virtual	void 						HandleNewCommand(
												CPLAT::OSStatus& inOutStatus,
												CPLAT::CP_CommandNo& inCommandNo );
	//@}

private:
	typedef CPLAT::CP_Application<CPLAT::CP_DocumentPolicy_Multi, CPLAT::CP_PrintPolicy_None, CPLAT::CP_UndoPolicy_None>	inherited;

	// class data
protected:
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

#endif	// _H_Threads_Application

