//=========================================================================
//
//	FILE:				CP_Clip.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A class to manage the clipping region of a platforms
//						graphics port.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 198 $
//						Latest Checkout:  $Date: 2005-06-01 23:15:21 -0700 (Wed, 01 Jun 2005) $
//
//=========================================================================
#ifndef _H_CP_Clip
#define _H_CP_Clip
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_NoCopy.h"
#include "CP_Rect.h"
#include "CP_Region.h"
#include "CP_Types.h"

	// forward class declarations
class CP_Canvas;

CPLAT_Begin_Namespace_CPLAT

//!  CP_Clip
/*!
  Maintain the clipping region for a CP_Canvas object.
*/
class CP_EXPORT CP_Clip : public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Clip();
										CP_Clip( const CP_Rect& inClipArea );
										CP_Clip( const CP_Region& inClipArea );
	//! Destructor.
	virtual								~CP_Clip();
	//@}

	//! @name Canvas
	//@{
			void						UseInCanvas( CP_Canvas *inDestCanvas = NULL );
	//@}

	//! @name Setters
	//@{

			void						Inset(
												SInt16 inHorAmt,
												SInt16 inVerAmt );

			void						Set( const CP_Rect& inClipArea );

										/*!
										*	Sets the region to be used for clipping.
										*
										*	@param		inClipRegion	The region to use to clip.
										*	
										*	@exception	none
										*	
										*	@return		void
										*/
			void						Set( const CP_Region& inClipRegion )		{ fClip = inClipRegion; }
	//@}


	//! @name Intersection
	//@{
			void						Intersect( const CP_Rect& inIntersect );
			void						Intersect( const CP_Region& inIntersect );
	//@}

	//! @name Save / Restore
	//@{
			void						Save();
			void						Restore();
	//@}
				
	//! @name Getters
	//@{
										/*!
										*	Returns the region used for clipping.
										*	
										*	@exception	none
										*	
										*	@return		CP_Region		The region used for clipping.
										*/
			CP_Region					GetClipRegion()								{ return( fClip ); }
	//@}

	// class data
protected:
	CP_Region							fClip;				/*! Current clipping region. */
	CP_Region							fSavedClip;			/*! Saved clipping region. */
		
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Clip

