//=========================================================================
//
//	FILE:				CP_DT_Memory.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Definitions of various MacOS memory management functions that
//						record allocation and deallocation for leak detection.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_DT_Memory
#define _H_CP_DT_Memory
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC

	// CPLAT_Framework
#include "CP_Types.h"

#if CP_Debug_RecordOSCalls

//==========================================================================
//	Memory Manager
//==========================================================================
#define BlockMove				CP_DT_DebugTrap_BlockMove
#define BlockMoveData			CP_DT_DebugTrap_BlockMoveData
#define NewPtr(sz)				CP_DT_DebugTrap_NewPtr( sz, __FUNCTION__, __FILE__, __LINE__ )
#define NewPtrClear(sz)			CP_DT_DebugTrap_NewPtrClear( sz, __FUNCTION__, __FILE__, __LINE__ )

#if ! TARGET_API_MAC_CARBON
	#define NewPtrSys(sz)		CP_DT_DebugTrap_NewPtrSys( sz, __FUNCTION__, __FILE__, __LINE__ )
	#define NewPtrSysClear(sz)	CP_DT_DebugTrap_NewPtrSysClear( sz, __FUNCTION__, __FILE__, __LINE__ )
#endif

#define GetPtrSize				CP_DT_DebugTrap_GetPtrSize
#define SetPtrSize				CP_DT_DebugTrap_SetPtrSize

#if ! TARGET_API_MAC_CARBON
	#define PtrZone				CP_DT_DebugTrap_PtrZone
#endif

#define DisposePtr				CP_DT_DebugTrap_DisposePtr
#define PtrToHand(s,d,z)		CP_DT_DebugTrap_PtrToHand( s, d, z, __FUNCTION__, __FILE__, __LINE__ )
#define NewHandle(sz)			CP_DT_DebugTrap_NewHandle( sz, __FUNCTION__, __FILE__, __LINE__ )
#define NewHandleClear(sz)		CP_DT_DebugTrap_NewHandleClear( sz, __FUNCTION__, __FILE__, __LINE__ )

#if ! TARGET_API_MAC_CARBON
	#define NewHandleSys(sz)		CP_DT_DebugTrap_NewHandleSys( sz, __FUNCTION__, __FILE__, __LINE__ )
	#define NewHandleSysClear(sz)	CP_DT_DebugTrap_NewHandleSysClear( sz, __FUNCTION__, __FILE__, __LINE__ )
#endif

#define GetHandleSize			CP_DT_DebugTrap_GetHandleSize
#define SetHandleSize(h,sz)		CP_DT_DebugTrap_SetHandleSize( h, sz )
#define ReallocateHandle		CP_DT_DebugTrap_ReallocateHandle
#define DisposeHandle			CP_DT_DebugTrap_DisposeHandle
#define HLock					CP_DT_DebugTrap_HLock
#define HUnlock					CP_DT_DebugTrap_HUnlock
#define HGetState				CP_DT_DebugTrap_HGetState
#define HSetState				CP_DT_DebugTrap_HSetState
#define HandAndHand				CP_DT_DebugTrap_HandAndHand
#define HandToHand(h)			CP_DT_DebugTrap_HandToHand( h, __FUNCTION__, __FILE__, __LINE__ )
#define HPurge					CP_DT_DebugTrap_HPurge
#define HNoPurge				CP_DT_DebugTrap_HNoPurge
#define EmptyHandle				CP_DT_DebugTrap_EmptyHandle

#define RecoverHandle			CP_DT_DebugTrap_RecoverHandle

#if ! TARGET_API_MAC_CARBON
	#define HandleZone			CP_DT_DebugTrap_HandleZone
	#define RecoverHandleSys	CP_DT_DebugTrap_RecoverHandleSys
	#define SetZone				CP_DT_DebugTrap_SetZone
	#define GetZone				CP_DT_DebugTrap_GetZone
#endif

#define TempNewHandle(sz, err)	CP_DT_DebugTrap_TempNewHandle( sz, err, __FUNCTION__, __FILE__, __LINE__ )
#define TempDisposeHandle		CP_DT_DebugTrap_TempDisposeHandle
#define MoveHHi					CP_DT_DebugTrap_MoveHHi
#define PtrAndHand				CP_DT_DebugTrap_PtrAndHand

pascal void 	CP_DT_DebugTrap_BlockMove(
						const void *srcPtr,
						void *destPtr,
						Size byteCount );
pascal void 	CP_DT_DebugTrap_BlockMoveData(
						const void *srcPtr,
						void *destPtr,
						Size byteCount );

pascal Ptr		CP_DT_DebugTrap_NewPtr(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );

#if ! TARGET_API_MAC_CARBON
pascal Ptr		CP_DT_DebugTrap_NewPtrSys(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Ptr		CP_DT_DebugTrap_NewPtrSysClear(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
#endif

pascal Ptr		CP_DT_DebugTrap_NewPtrClear(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Size		CP_DT_DebugTrap_GetPtrSize( Ptr p );
pascal void		CP_DT_DebugTrap_SetPtrSize(
						Ptr p,
						Size newSize );

#if ! TARGET_API_MAC_CARBON
pascal THz		CP_DT_DebugTrap_PtrZone( Ptr p );
#endif

pascal void		CP_DT_DebugTrap_DisposePtr( Ptr p );

pascal OSErr	CP_DT_DebugTrap_PtrToHand(
						const void *srcPtr,
						Handle *dstHndl,
						long size,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle	CP_DT_DebugTrap_NewHandle(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle	CP_DT_DebugTrap_NewHandleClear(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );

#if TARGET_API_MAC_CARBON
pascal Handle	CP_DT_DebugTrap_NewHandleSys(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal Handle	CP_DT_DebugTrap_NewHandleSysClear(
						Size byteCount,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
#endif

pascal Size 	CP_DT_DebugTrap_GetHandleSize( Handle h );
pascal void 	CP_DT_DebugTrap_SetHandleSize(
						Handle h,
						Size newSize );
pascal void		CP_DT_DebugTrap_ReallocateHandle(
						Handle h,
						Size byteCount );
pascal void 	CP_DT_DebugTrap_DisposeHandle( Handle h );
pascal void 	CP_DT_DebugTrap_HLock( Handle h );
pascal void 	CP_DT_DebugTrap_HUnlock( Handle h );
pascal SInt8	CP_DT_DebugTrap_HGetState( Handle h );
pascal void		CP_DT_DebugTrap_HSetState(
						Handle h,
						SInt8 flags );
pascal OSErr 	CP_DT_DebugTrap_HandAndHand(
						Handle hand1,
						Handle hand2 );
pascal OSErr	CP_DT_DebugTrap_HandToHand(
						Handle *theHndl,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal void		CP_DT_DebugTrap_HPurge( Handle h );
pascal void		CP_DT_DebugTrap_HNoPurge( Handle h );
pascal void		CP_DT_DebugTrap_EmptyHandle( Handle h );
pascal THz		CP_DT_DebugTrap_HandleZone( Handle h );
pascal Handle	CP_DT_DebugTrap_RecoverHandle( Ptr p );

#if ! TARGET_API_MAC_CARBON
pascal Handle	CP_DT_DebugTrap_RecoverHandleSys( Ptr p );
#endif

pascal void		CP_DT_DebugTrap_MoveHHi( Handle h );
pascal OSErr	CP_DT_DebugTrap_PtrAndHand(
						const void *ptr1,
						Handle hand2, long size );

#if ! TARGET_API_MAC_CARBON
pascal void		CP_DT_DebugTrap_SetZone( THz hz );
pascal THz		CP_DT_DebugTrap_GetZone();
#endif

pascal Handle	CP_DT_DebugTrap_TempNewHandle(
						Size logicalSize,
						OSErr *resultCode,
						const char *inFunction,
						const char *inFile,
						SInt16 inLine );
pascal void		CP_DT_DebugTrap_TempDisposeHandle(
						Handle h,
						OSErr *err );

	// Utility functions
bool 		CP_DT_HandleIsPurgeable( Handle h );
bool 		CP_DT_HandleIsLocked( Handle h );
bool 		CP_DT_HandleIsPurgeableAndNotLocked( Handle h );

bool 		CP_DT_SetIgnoreDebugWarning( bool ignoreDebugWarning );		// turn warnings on/off

#endif	// __CP_USE_DEBUG_TRAPS__

#endif	// __BUILD_MAC__

#endif	// _H_CP_DT_Memory
