//=========================================================================
//
//	FILE:				CP_HTTP.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class to implement the HTTP protocol.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_HTTP
#define _H_CP_HTTP
#ifndef __BUILD_LINUX__
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_NetProtoBase.h"
#include "CP_Socket.h"
#include "CP_Types.h"

	// MSL
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

CPLAT_Begin_Namespace_CPLAT

#define MEM_BUFFER_SIZE 10

	// Structure that returns the HTTP headers and message.
typedef struct
{ 
	char		*fHeaderSend;			// Pointer to HTTP header Send 
	char		*fHeaderReceive;		// Pointer to HTTP headers Receive
    char		*fMessage;				// Pointer to the HTTP message 
	SInt32		fMessageLength;			// Length of the message 
} HTTPCP_HTTP;

	// Structure used to hold variable sized parts of the HTTP message. 
typedef struct
{
	unsigned char		*fBuffer;
	unsigned char		*fPosition;
	size_t 				fSize;
} MemBuffer;

/*!
*	@class		CP_HTTP
*	@brief		CP_NetProtoBase to implement the HTTP protocol for posting and getting data from a url.
*
*				Example useage:
*
*	@code
*					CP_Socket			socket;
*					CP_HTTP				*httpRequest = CP_new CP_HTTP( &socket );
*					CP_String			psHeaderSend;
*					CP_String			psHeaderReceive;
*					CP_String			psMessage;
*					
*					httpRequest->SendRequest( false, "http://www.ksoft.net", psHeaderSend, psHeaderReceive, psMessage );
*					
*						psSend -- contains the message sent
*						psReceive -- contains the results of the sent message
*						psMessage -- contains the returned result from the server
*	@endcode
*/
class CP_HTTP : public CP_NetProtoBase
{
public:
	/*! The port number used for this class. */
	enum { kCP_HTTPPortNumber = 80 };

	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_HTTP( CP_Socket *inSocketConnection );
	//! Destructor.
	virtual								~CP_HTTP() throw();
	//@}

	//! @name Sendinng
	//@{
			void						SendRequest(
												bool InIsPOST,
												char *inUrl,
												CP_String& inOutHeaderSend,
												CP_String& inOutHeaderReceive,
												CP_String& inOutMessage );
	//@}

protected:												
	//! @name Misc
	//@{
			void						ParseURL(
												char *inUrl,
												char *inProtocol,
												SInt32 inProtocolLength,
												char *inHost,
												SInt32 inHostLength,
												char *inHTTPBuffer,
												SInt32 inHTTPBufferLength,
												SInt32 *port );
	//@}

	//! @name Sending
	//@{
			SInt32						SendHTTP(
												char *inUrl,
												char *inHeaders,
												unsigned char *inPost,
												SInt32 inPostLength,
												HTTPCP_HTTP *inRequest );

			void						SendString( char *inString );
	//@}
			
	//! @name Memory Buffer
	//@{
			void						MemBufferCreate( MemBuffer *inMemBuffer );
			void						MemBufferGrow( MemBuffer *inMemBuffer );
			void						MemBufferAddByte(
												MemBuffer *inMemBuffer,
												unsigned char inByte );
			void						MemBufferAddBuffer(
												MemBuffer *inMemBuffer,
												unsigned char *inBuffer,
												size_t inSize );
	//@}

	//! @name Tester
	//@{
			bool						IsValidHostchar( char inchar );
	//@}

	// class data
protected:
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_HTTP
