//=========================================================================
//
//	FILE:				CP_InternetResponse.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Base class to handle responses from our internet servers.
//
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 22 $
//						Latest Checkout:  $Date: 2004-12-28 19:35:48 -0800 (Tue, 28 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_InternetResponse
#define _H_CP_InternetResponse
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Object.h"
#include "CP_Socket.h"
#include "CP_String.h"
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

	// status code length
const size_t kCP_STATUS_CODE_LENGTH					= 3;

/*!
*	@class		CP_InternetResponse
*	@brief		Base class to handle responses from internet servers. Each different
*				protocol will have a specific class of this type to handle and format
*				responses for that protocol.
*/
class CP_EXPORT CP_InternetResponse
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_InternetResponse( CP_Socket *inSocket );
										CP_InternetResponse( const CP_InternetResponse& inResponse );
	//! Destructor.
	virtual								~CP_InternetResponse() throw();
	//@}

	//! @name Getters
	//@{
										/*!
										*	Return the text of the response.
										*	
										*	@exception	none
										*
										*	@return		CP_String		The response string.
										*/
				CP_String				GetResponseString()									{ return( fServerResponseString ); }

										/*!
										*	Return the text of the response.
										*	
										*	@exception	none
										*
										*	@return		CP_String		The response string.
										*/
				CP_String				GetBodyString()										{ return( fServerBodyString ); }

										/*!
										*	Return the resonse code
										*	
										*	@exception	none
										*
										*	@return		SInt32			The response code.
										*/
				SInt32					GetResponseCode()									{ return( fServerResponseCode ); }

	virtual		bool					GetServerResponse();
	//@}

	//! @name Setters
	//@{
										/*!
										*	Sets the text of the response. This text comes from the server.
										*
										*	@param		inResponse		The servers response.
										*	
										*	@exception	none
										*
										*	@return		void
										*/
				void					SetResponseString( const CP_String& inResponse )	{ fServerResponseString = inResponse; }

										/*!
										*	Sets the response code. This text comes from the server.
										*
										*	@param		inResponseCode	The servers response code.
										*	
										*	@exception	none
										*
										*	@return		void
										*/
				void					SetResponseCode( SInt32 inResponseCode )				{ fServerResponseCode = inResponseCode; }

				void					ResetResponse();
	//@}
				
protected:
	//! @name Misc
	//@{
				SInt32					ReadLine(
												CP_Socket *inSocket,
												CP_String& inOutResult );
	//@}
	
private:

	// class data
protected:
										
	CP_String							fServerResponseString;		/*! CP_String containing the response from the server. */
	CP_String							fServerBodyString;			/*! CP_String containing the body of the response from the server */
										
	SInt32								fServerResponseCode;		/*! Any numeric response code from the server. */
	
	CP_Socket							*fSocketConnection;			/*! CP_Socket conntection with the server. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_InternetResponse


