//=========================================================================
//
//	FILE:				CP_KeyboardDefines.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Definitionns for common keys.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_KeyboardDefines
#define _H_CP_KeyboardDefines
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

#if TARGET_OS_MAC
	const unsigned char CP_CharEnter         		= 0x03;

	const unsigned char CP_CharBackspace        	= 0x08;
	const unsigned char CP_CharTab          		= 0x09;

	const unsigned char CP_CharReturn      			= 0x0D;

	const unsigned char CP_CharEscape				= 0x1B;

	const unsigned char CP_CharSpace				= 0x20;

	const unsigned char CP_TabKey					= 0x30;		// 'TAB'
	const unsigned char CP_EscapeKey				= 0x35;		// 'ESC'
	const unsigned char CP_CommandKey				= 0x37;		// 'CLOVER'
	const unsigned char CP_ShiftKey					= 0x38;		// 'SHIFT'
	const unsigned char CP_OptionKey				= 0x3A;		// 'OPTION'
	const unsigned char CP_ControlKey				= 0x3B;		// 'CONTROL'

		// Function keys
	const unsigned char CP_Char_F1					= 0x7A;
	const unsigned char CP_Char_F2					= 0x78;
	const unsigned char CP_Char_F3					= 0x63;
	const unsigned char CP_Char_F4					= 0x76;
	const unsigned char CP_Char_F5					= 0x60;
	const unsigned char CP_Char_F6					= 0x61;
	const unsigned char CP_Char_F7					= 0x62;
	const unsigned char CP_Char_F8					= 0x64;
	const unsigned char CP_Char_F9					= 0x65;
	const unsigned char CP_Char_F10			 		= 0x6D;
	const unsigned char CP_Char_F11			 		= 0x67;
	const unsigned char CP_Char_F12			 		= 0x6F;
	const unsigned char CP_Char_F13			 		= 0x69;
	const unsigned char CP_Char_F14			 		= 0x6B;
	const unsigned char CP_Char_F15			 		= 0x71;
	
	const unsigned char CP_CharPrintScreen			= 0x69;

	const unsigned char CP_CharLeftArrow	 		= 0x1C;
	const unsigned char CP_CharRightArrow			= 0x1D;
	const unsigned char CP_CharUpArrow	 			= 0x1E;
	const unsigned char CP_CharDownArrow			= 0x1F;

	const unsigned char CP_CharHome					= 0x01;
	const unsigned char CP_CharEnd		 			= 0x04;
	const unsigned char CP_CharPageUp				= 0x0B;
	const unsigned char CP_CharPageDown		 		= 0x0C;
#endif

#if TARGET_OS_WIN32
	const unsigned char CP_CharEnter         		= VK_RETURN;
	
	const unsigned char CP_CharBackspace         	= VK_BACK;
	const unsigned char CP_CharTab            		= VK_TAB;

	const unsigned char CP_CharReturn         		= VK_RETURN;

	const unsigned char CP_CharEscape         		= VK_ESCAPE;

	const unsigned char CP_CharSpace          		= VK_SPACE;

	const unsigned char CP_TabKey					= VK_TAB;
	const unsigned char CP_EscapeKey				= VK_ESCAPE;
	const unsigned char CP_ShiftKey					= VK_SHIFT;
	const unsigned char CP_ControlKey				= VK_CONTROL;
	const unsigned char CP_AltKey					= VK_MENU;
	const unsigned char CP_OptionKey				= VK_MENU;		// jsc
	
		// the following virtual key codes collide with the ascii pritable char set
		// so we move them into VK-unassigned, non-printable ASCII space
		// translation happens in CP_Window's WM_KEYDOWN handler (jsc)

	const unsigned char CP_CharLeftArrow	 		= 0xC1;	// VK_LEFT;
	const unsigned char CP_CharRightArrow			= 0xC2;	// VK_RIGHT;
	const unsigned char CP_CharUpArrow		 		= 0xC3;	// VK_UP;
	const unsigned char CP_CharDownArrow			= 0xC4;	// VK_DOWN;

	const unsigned char CP_CharHome					= 0xC5;	// VK_HOME;
	const unsigned char CP_CharEnd			 		= 0xC6;	// VK_END;
	const unsigned char CP_CharPageUp				= 0xC7;	// VK_PRIOR;
	const unsigned char CP_CharPageDown		 		= 0xC8;	// VK_NEXT;

	const unsigned char CP_CharPrintScreen			= 0xC9;	// VK_SNAPSHOT;
	const unsigned char CP_CharInsert				= 0xCA;	// VK_INSERT;
	const unsigned char CP_CharDelete				= 0xCB;	// VK_DELETE;

		// Function keys
	const unsigned char CP_Char_F1					= 0xCC;	// VK_F1;
	const unsigned char CP_Char_F2					= 0xCD;	// VK_F2;
	const unsigned char CP_Char_F3					= 0xCE;	// VK_F3;
	const unsigned char CP_Char_F4					= 0xCF;	// VK_F4;
	const unsigned char CP_Char_F5					= 0xD0;	// VK_F5;
	const unsigned char CP_Char_F6					= 0xD1; // VK_F6;
	const unsigned char CP_Char_F7					= 0xD2; // VK_F7;
	const unsigned char CP_Char_F8					= 0xD3; // VK_F8;
	const unsigned char CP_Char_F9					= 0xD4; // VK_F9;
	const unsigned char CP_Char_F10			 		= 0xD5; // VK_F10;
	const unsigned char CP_Char_F11			 		= 0xD6; // VK_F11;
	const unsigned char CP_Char_F12			 		= 0xD7; // VK_F12;
	const unsigned char CP_Char_F13			 		= 0xD8; // VK_F13;
	const unsigned char CP_Char_F14			 		= 0xD9; // VK_F14;
	const unsigned char CP_Char_F15			 		= 0xDA; // VK_F15;

#endif

#if TARGET_OS_WIN32
	inline UInt32 VirtualKeyToCplatKey( UInt32 key) 
	{
		if (key == VK_LEFT)				return CP_CharLeftArrow;
		else if (key == VK_RIGHT)		return CP_CharRightArrow;
		else if (key == VK_UP)			return CP_CharUpArrow;
		else if (key == VK_DOWN)		return CP_CharDownArrow;
		else if (key == VK_HOME)		return CP_CharHome;
		else if (key == VK_END)			return CP_CharEnd;
		else if (key == VK_PRIOR)		return CP_CharPageUp;
		else if (key == VK_NEXT)		return CP_CharPageDown;
		else if (key == VK_SNAPSHOT)	return CP_CharEnd;
		else if (key == VK_INSERT)		return CP_CharInsert;
		else if (key == VK_DELETE)		return CP_CharDelete;
		else if (key == VK_F1)			return CP_Char_F1;
		else if (key == VK_F2)			return CP_Char_F2;
		else if (key == VK_F3)			return CP_Char_F3;
		else if (key == VK_F4)			return CP_Char_F4;
		else if (key == VK_F5)			return CP_Char_F5;
		else if (key == VK_F6)			return CP_Char_F6;
		else if (key == VK_F7)			return CP_Char_F7;
		else if (key == VK_F8)			return CP_Char_F8;
		else if (key == VK_F9)			return CP_Char_F9;
		else if (key == VK_F10)			return CP_Char_F10;
		else if (key == VK_F11)			return CP_Char_F11;
		else if (key == VK_F12)			return CP_Char_F12;
		else if (key == VK_F13)			return CP_Char_F13;
		else if (key == VK_F14)			return CP_Char_F14;
		else if (key == VK_F15)			return CP_Char_F15;
		
		return key;
	}
#endif

#if TARGET_OS_LINUX
	const unsigned char CP_CharEnter         		= 0x03;

	const unsigned char CP_CharBackspace        	= 0x08;
	const unsigned char CP_CharTab           		= 0x09;

	const unsigned char CP_CharReturn         		= 0x0D;

	const unsigned char CP_CharEscape				= 0x1B;

	const unsigned char CP_CharSpace				= 0x20;

	const unsigned char CP_TabKey					= 0x30;		// 'TAB'
	const unsigned char CP_EscapeKey				= 0x35;		// 'ESC'
	const unsigned char CP_CommandKey				= 0x37;		// 'CLOVER'
	const unsigned char CP_ShiftKey					= 0x38;		// 'SHIFT'
	const unsigned char CP_OptionKey				= 0x3A;		// 'OPTION'
	const unsigned char CP_ControlKey				= 0x3B;		// 'CONTROL'
#endif


CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_KeyboardDefines

