//=========================================================================
//
//	FILE:				CP_Palette.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A class to represent the color palette used with a
//						platforms graphics port.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Palette
#define _H_CP_Palette
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_M_ReferenceCounted.h"
#include "CP_NoCopy.h"
#include "CP_RGBColor.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_Palette
*	@brief		A class to represent the color palette used with a platforms graphics port.
*/
class CP_EXPORT CP_Palette : public CP_M_RefCounted, public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Palette();
										CP_Palette(
												UInt16 inNumberColors,
												bool inWantSystemDefault = true,
												bool inWantBW = false );
										CP_Palette( SInt32 inCLUTResourceID );
	//@}
	//! Destructor.
	virtual								~CP_Palette() throw();
	//@}
									
	//! @name Converters
	//@{
			UInt32						BitDepthToNumberColors( SInt16 inBitDepth );
			SInt16						NumberColorsToBitDepth( UInt32 inNumberColors );
	//@}

	//! @name Getters
	//@{
			SInt16						GetCount() const;
			CP_RGBColor					GetColorEntry( SInt16 inIndex ) const;
			SInt16						GetColorIndex( const CP_RGBColor& inColor );
	//@}
			
	//! @name Setters
	//@{
			void						SetColorEntry(
												SInt16 inIndex,
												const CP_RGBColor& inColor );
	//@}

	// class data
protected:
	#if TARGET_OS_MAC
		CTabHandle						fColorTable;	/*! A MacOS CTabHandle containing the colors. */
		bool							fFromSystem;	/*! A MacOS CTabHandle containing the colors. */
	#endif
	#if TARGET_OS_WIN32
									
		HPALETTE						fColorTable;	/*! Windows color table. */
									
		LPLOGPALETTE					fLogPalette;	/*! Window palette. */
	#endif
	#if TARGET_OS_LINUX
		char							*fColorTable;	/*! Linux color table. */
	#endif

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Palette( CTabHandle inColorTable );
	//@}
								
	//! @name Getters
	//@{
											// Getters
										/*! Return a MacOS CTabHandle containing the colors in the palette. */
			CTabHandle					GetColorTable()										{ return( fColorTable ); }
	//@}

private:
	//! @name Misc
	//@{
			void						MakeMacOSColorTable( UInt16 inNumberColors );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Palette(
												SInt32 *inColorTable,
												SInt16 inNumberColors );
	//@}

	//! @name Getters
	//@{
										/*! Return the Windows color table. */
			HPALETTE					GetColorTable()									{ return( fColorTable ); }
	//@}

private:
	//! @name Misc
	//@{
			bool						LoadCLUT( SInt32 inCLUTResourceID );

			void						CreateDefaultWinPalette( UInt16 inBitDepth );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Palette


