//=========================================================================
//
//	FILE:				CP_Point.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class for handling a point measurement using floating
//						point coordinates.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Point
#define _H_CP_Point
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_Enums.h"
#include "CP_Size.h"
#include "CP_Types.h"

#ifdef __CF_USE_FRAMEWORK_INCLUDES__
	#include <Carbon/Carbon.h>				// Carbon framework
#endif

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_Point
*	@brief		A class for representing a point using floating point coordinates.
*	
*				This class is used to express all coordinates in CPLAT.
*/
class CP_EXPORT CP_Point
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Point();
										CP_Point(
												float inHor,
												float inVer );
										CP_Point( const CP_Point& inFloatPoint );
	//! Destructor.
										~CP_Point();
	//@}
			
	//! @name Comparers
	//@{
			bool						operator == ( const CP_Point& inPoint ) const;
			bool						operator != ( const CP_Point& inPoint ) const;
			bool						operator >= ( const CP_Point& inPoint ) const;
			bool						operator <= ( const CP_Point& inPoint ) const;

			bool						operator > ( const CP_Point& inPoint );
			bool						operator < ( const CP_Point& inPoint );
	//@}
							
	//! @name Getters
	//@{
										/*!
										*	Return the horizontal or x coordinate.
										*	
										*	@return	float const		Horizontal coordinate
										*/
			float						h() const										{ return( fHorizontalCoord ); }

										/*!
										*	Return the vertical or y coordinate.
										*	
										*	@return	float const		Vertical coordinate
										*/
			float						v() const										{ return( fVerticalCoord ); }
	//@}

	//! @name Negative
	//@{
			CP_Point					operator -() const;
	//@}

	//! @name Math
	//@{
			CP_Point&					operator += ( const CP_Point& inPoint );
			CP_Point&					operator -= ( const CP_Point& inPoint );
			CP_Point&					operator *= ( const CP_Point& inPoint );
			CP_Point&					operator /= ( const CP_Point& inPoint );


			CP_Point&					operator += ( const CP_Size& inSize );
			CP_Point&					operator -= ( const CP_Size& inSize );

			CP_Point					operator + ( const CP_Point& inPoint ) const;
			CP_Point					operator - ( const CP_Point& inPoint ) const;
			CP_Point					operator * ( const CP_Point& inPoint ) const;
			CP_Point					operator / ( const CP_Point& inPoint ) const;

			CP_Point&					operator = ( const CP_Point& );
	//@}

	//! @name Movement
	//@{
			void						Offset(
												const float horAmt,
												const float verAmt );
	//@}

	//! @name Selectors
	//@{
			float						operator[](CP_VHSelector sel);
	const 	float						operator[](CP_VHSelector sel) const;
	//@}

	//! @name Setters
	//@{
			void						Set(
												const float inHor,
												const float inVer );
			void						Set( const CP_Point& inPoint );

			void						SetH( const float inHor )						{ fHorizontalCoord = inHor; }
			void						SetV( const float inVer )						{ fVerticalCoord = inVer; }
	//@}
			

	//! @name Utility
	//@{
			void						MakeEmpty();
	//@}

protected:

	// class data
protected:
	float								fHorizontalCoord;		/*! Horizontal coordinate. */
	float								fVerticalCoord;			/*! Vertical coordinate. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	#if UNIVERSAL_INTERFACES_VERSION >= 0x0400
	//! @name HIPoint
	//@{
										CP_Point( HIPoint inRect );

										operator HIPoint *();
										operator const HIPoint *() const;
										operator const HIPoint () const;

			CP_Point&					operator = ( HIPoint inRect );
	//@}
	#endif	// UNIVERSAL_INTERFACES_VERSION 0x0400

	//! @name Point
	//@{
										CP_Point( const Point& inPoint );

										operator Point();
										operator const Point() const;
										operator Point *();
										operator const Point *() const;

			CP_Point&					operator = ( Point inPoint );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	//! @name POINT
	//@{
										CP_Point( const POINT& inPoint );

										operator POINT();
										operator const POINT() const;

			CP_Point&					operator = ( POINT inPoint );
	//@}
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Point

