//=========================================================================
//
//	FILE:				CP_PropertyList_BinaryData.h
//	
//						Created by Jens Miltner on 01.12.04.
//	
//	PURPOSE:			CP_PropertyList binary data.
//	
//	HISTORY:			1st Version - January 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 115 $
//						Latest Checkout:  $Date: 2005-03-24 16:55:37 -0800 (Thu, 24 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_PropertyList_BinaryData
#define _H_CP_PropertyList_BinaryData

#include "CP_PropertyList_Node.h"
#include "CP_CFMutableObject.h"

CPLAT_Begin_Namespace_CPLAT

namespace CP_PropertyList {

	class CP_EXPORT BinaryData : public Node
#if CP_PropertyList_Uses_CoreFoundation
		, CP_CFMutableObject<CFDataRef, CFMutableDataRef>
#endif
{
	public:
		//! @name Constructor/Destructor
		//! @{
		BinaryData();
		explicit BinaryData(const void* inBuffer, UInt32 inBufferSize, bool inMutable=false);
		BinaryData(const BinaryData& inSrc);
	#if CP_PropertyList_Uses_CoreFoundation
		explicit BinaryData(CFDataRef inDataRef, bool inRetain=true);
	#endif
		virtual ~BinaryData() throw();
		//! @}
		
		//! @name immutable operations
		//! @{
		//! Return byte size of data.
		UInt32 GetDataSize() const;
		//! Return an immutable pointer to the data.
		const void* GetDataPtr() const;
		//! Copy the data into the specified buffer.
		UInt32 CopyBytes(void* inBuffer, UInt32 inByteCount, UInt32 inStartOffset=0) const;
		//! @}
		
		//! @name mutable members (will/can modify data)
		//! @{
		//! Get a mutable pointer to the data.
		void* GetMutableDataPtr();
		//! Change the byte size of the data.
		void SetDataSize(UInt32 inNewDataSize);
		//! Increase the byte size of the data, filling with zeroes.
		void IncreaseDataSize(UInt32 inExtraSize);
		void AppendBytes(const void* inBuffer, UInt32 inByteCount);
		void ReplaceBytes(const void* inBuffer, UInt32 inByteCount, UInt32 inStartOffset, UInt32 inBytesToReplace);
		void DeleteBytes(UInt32 inStartOffset, UInt32 inByteCount);
		//! @}
		
		//! Make a mutable binary data object with the same contents.
		BinaryData* MakeMutable() const;
		
		//! @name Node members that need overloading
		//! @{
		virtual NodeType_t NodeType() const throw();
		static BinaryData* FromXMLData(CP_InStream& inXMLDataStream);		
		virtual void PrintToLog(CP_LogFile& inLogFile, SInt32 inLevel=0, SInt32 inIndentLevel=0) const;
	#if CP_PropertyList_Uses_CoreFoundation
		virtual CFTypeRef/*CFDataRef*/ GetNodeCFRef() const;
	#endif
	#if !CP_PropertyList_Uses_CoreFoundation
	protected:
		//! write XML data for this node only (i.e. without xml header, plist root, etc.)
		virtual void WriteNodeXMLData(CP_OutStream& inXMLDataStream, int inLeadingSpaces) const;
	#endif
		//! @}

		// class data:
	protected:
	#if !CP_PropertyList_Uses_CoreFoundation
		void   *fpData;    // pointer to our binary data
		UInt32 fDataSize;  // size of the binary data
		
		
	#endif
	};


} // end of namespace CP_PropertyList

CPLAT_End_Namespace_CPLAT

#endif // _H_CP_PropertyList_BinaryData
