//=========================================================================
//
//	FILE:				CP_Startup.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Class used to manage startup of CPLAT applications.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 106 $
//						Latest Checkout:  $Date: 2005-03-21 15:03:06 -0800 (Mon, 21 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_Startup
#define _H_CP_Startup
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_NoCopy.h"
#include "CP_Types.h"
#include "CP_STLArrayDefines.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_Startup
*	@brief		Class used to manage startup of CPLAT applications.
*/
class CP_EXPORT CP_Startup : CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Startup()													{}
										CP_Startup(
												int argc,
												char *argv[] );
	//! Destructor.
	virtual								~CP_Startup();
	//@}
			
	//! @name Getters
	//@{
	/*!
	*	Return the command line arguments passed in at startup.
	 *
	 *	@exception	none
	 *	
	 *	@return		const CP_Strings_Array&	The list of commandline arguments.
	 */
	static const CP_Strings_Array&		GetArguments()					{ return( fArguments ); }
	//@}
	
protected:

private:

	// class data
protected:

#if TARGET_OS_WIN32
	static	HINSTANCE					fhInst;				/*! HINSTANCE of this application. */
	static	HINSTANCE					fhPrevInst;			/*! HINSTANCE of any other running application. */
	static	LPSTR						fzCmdLine;			/*! Command line passed in from main. */
	static	INT							fsCmdShow;			/*! Show parameter to determine initial state of windows. */

	static bool							fsOLEInstalled;		/*! Has OLE been initialized. */
	static	HRESULT						fhr;				/*! Result from initializing OLE. */
#endif
	static CP_Strings_Array				fArguments; /*! Command line arguments passed in from main */
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
	//! @name Initialization
	//@{
			void						InitPlatform(
												int argc,
												char *argv[] );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	//! @name Constructor / Destructor
	//@{
										CP_Startup( 
													HINSTANCE hInst,
													HINSTANCE hPrevInst,
													LPSTR zCmdLine,
													INT sCmdShow );
	//@}

	//! @name Getters
	//@{
										/*!
										*	Return the HINSTANCE of ourselves.
										*
										*	@exception	none
										*	
										*	@return		HINSTANCE	The Windows HINSTANCE of this application.
										*/
	static HINSTANCE					GetInstance()										{ return( fhInst ); }

										/*!
										*	Return the previous HINSTANCE of this application.
										*
										*	@exception	none
										*	
										*	@return		HINSTANCE	The Windows previous HINSTANCE of this application.
										*/
	static HINSTANCE					GetPrevInstance()									{ return( fhPrevInst ); }

										/*!
										*	Return the command line passed into the application at startup.
										*
										*	@exception	none
										*	
										*	@return		LPSTR		The command line.
										*/
	static LPSTR						GetCommandLine()									{ return( fzCmdLine ); }

										/*!
										*	Return the command show flag. 
										*
										*	@exception	none
										*		
										*	@return		INT			The command show flag passed in at startup.
										*/
	static INT							GetCommandShow()									{ return( fsCmdShow ); }
	//@}

	static bool							IsOLEInited()										{ return( fsOLEInstalled ); }

	static void							InitOLE();

private:
	//! @name Initialization
	//@{
			void						InitPlatform();
			void						InitPlatform(
												int argc,
												char *argv[] );
	//@}
#endif

#if TARGET_OS_LINUX
private:
	//! @name Initialization
	//@{
			void						InitPlatform(
												int argc,
												char *argv[] );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_Startup

