//=========================================================================
//
//	FILE:				CP_GetFileDialog.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Presents the platforms GetFileDialog.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 234 $
//						Latest Checkout:  $Date: 2005-07-17 19:53:23 -0700 (Sun, 17 Jul 2005) $
//
//=========================================================================
#ifndef _H_CP_GetFileDialog
#define _H_CP_GetFileDialog
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_FileSystemSpec.h"
#include "CP_FileSystemDialogsReply.h"

	// Standard Library
#include <vector>

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_GetFileDialog
*	@brief		Presents the platforms GetFileDialog.
*/
class CP_EXPORT CP_GetFileDialog : public CP_FileSystemDialogs_Reply
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_GetFileDialog();
	//! Destructor.		
	virtual								~CP_GetFileDialog() throw();
	//@}
			
	//! @name Getters
	//@{
										/*!
										*	Returns the list of selected files.
										*	
										*	@exception	none
										*	
										*	@return		CP_FileSystemSpec_Array			Selected files.
										*/
			CP_FileSystemSpec_Array		GetSelectedFilesList()							{ return( fSelectedFiles ); }
	//@}

protected:
	//! @name Dialog handlers
	//@{
	virtual	void						HandleUserAction(
												CP_FileSystemDialogs_Base *inSendingDialog,
												CP_E_NavDialogResult inNavDialogResult );
	//@}

	// class data
protected:
	CP_FileSystemSpec_Array				fSelectedFiles;		/*! Selected files by user */
			
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
protected:
	//! @name Dialog handlers
	//@{
	virtual	NavDialogRef				CreateDialog(
												NavDialogCreationOptions& inOptions, 
												NavEventUPP inEventUPP,
												void *inUserData );

	virtual	void						ProcessReply();
	//@}
#endif

#if TARGET_OS_WIN32
protected:
	//! @name Dialog handlers
	//@{
	virtual	void						RunPlatformDialog();

	static UINT APIENTRY				CP_SelectFileHook(
												HWND hWnd,
												UINT uMsg,
												WPARAM wParam,
												LPARAM lParam );
	//@}
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_GetFileDialog

