//=========================================================================
//
//	FILE:				CP_XMLWriter_Comment.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			A class to handle comments used with our XML_Writer.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 10 $
//						Latest Checkout:  $Date: 2004-12-24 14:46:10 -0800 (Fri, 24 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_XMLWriter_Comment
#define _H_CP_XMLWriter_Comment
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_String.h"
#include "CP_Types.h"
#include "CP_XMLWriter_Element.h"

CPLAT_Begin_Namespace_CPLAT

	// forward references
class CP_EXPORT CP_XMLWriter;

/*!
*	@class		CP_XMLWriter_Comment
*	@brief		This class is used with the CP_XMLWriter class to write comments out to
*				the XML file. You supply the comment as a CP_String, and this class will
*				take care of formatting it correctly for output.
*
*	@ingroup	XML
*/
class CP_EXPORT CP_XMLWriter_Comment : public CP_XMLWriter_Entry
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_XMLWriter_Comment(
												CP_XMLWriter *inXMLWriter,
												CP_XMLWriter_Entry *inParentElement,
												const CP_String& inComment );
	//! Destructor.
	virtual								~CP_XMLWriter_Comment();
	//@}

	//! @name Writing
	//@{
											// Normally you would not need to call this method
											// and instead just call Write.
			void						WriteHeader( CP_XMLWriter *inXMLWriter = NULL );
	//@}

private:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_XMLWriter_Comment( const CP_XMLWriter_Comment& inWriter );
	//@}

	//! @name operators
	//@{
			CP_XMLWriter_Comment&		operator =( const CP_XMLWriter_Comment& inXMLWriter );
	//@}

	// class data members
protected:
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_XMLWriter_Comment


