//=========================================================================
//
//	FILE:				CP_File_Imp_Gtk.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			MacOS implementation of CP_File.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 4 $
//						Latest Checkout:  $Date: 2004-12-22 19:17:46 -0800 (Wed, 22 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_File_Imp_Gtk
#define _H_CP_File_Imp_Gtk
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_LINUX

	// CPLAT_Framework
#include "CP_Data_ResourceTypes.h"
#include "CP_Enums.h"
#include "CP_FileSystemSpec.h"
#include "CP_NoCopy.h"
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class	CP_File_Mac_Imp
*	@brief	Linux / Gtk implementation of CP_File.
*/
class CP_EXPORT CP_File_Imp : public CP_NoCopy
{
public:
									// Construction / destruction
										CP_File_Imp();
										CP_File_Imp( const CP_FileSystemSpec& inFileSpec );
	virtual								~CP_File_Imp();
			
			void						Create(
												FourCharCode inCreator,
												FourCharCode inType = kCP_Text_FileType );

			void						Open( SInt16 inPermissions = CP_E_FilePerm_ReadWrite );
			void 						Close();
						
											// Length
			SInt64						Length();

									// Position
			SInt64						GetPosition() const;
			SInt64						SetPosition(
												UInt16 inMode,
												SInt64 inOffset );

									// Read / Write
			UInt32						ReadData(
												void *inDataBuffer,
												UInt32 inDataSize,
												UInt16 inPositionMode = CP_E_FileSeek_FromCurrent,
												SInt64 inOffset = 0 );
			UInt32						WriteData(
												const void *inDataBuffer,
												UInt32 inDataSize,
												UInt16 inPositionMode = CP_E_FileSeek_FromCurrent,
												SInt64 inOffset = 0 );

									// Testers
			bool						IsOpen()																{ return( false/*fRefNum != kCP_BadFileRefNum*/ ); }							

protected:

	// class data
protected:
	CP_FileSystemSpec					fFileSpec;		/*! CP_FileSystemSpec containing the name and location of this file. */
	OSFileRef							fRefNum;		/*! Linux file reference number for file when open. */
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_LINUX

#endif	// _H_CP_File_Imp_Gtk

