//=========================================================================
//
//	FILE:				CP_UPPs.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Template classes to manage the creation and destruction
//						of MacOS UPPs.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_UPPs
#define _H_CP_UPPs
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_MAC

	// CPLAT_Framework
#include "CP_Exceptions.h"
#include "CP_NoCopy.h"

CPLAT_Begin_Namespace_CPLAT

template <typename PROC_PTR, typename UPP, UPP (*NEW)(PROC_PTR), void (*DISPOSE)(UPP)>
class CP_UPP : public CP_NoCopy
{
public:
									// Construction / destruction
								CP_UPP( PROC_PTR inUserRoutine );
								~CP_UPP() throw();

								operator UPP () const
									{
										return( fUPP );
									}
	
	// class data
private:
	UPP							fUPP;
};

template <typename PROC_PTR, typename UPP, UPP (*NEW)(PROC_PTR), void (*DISPOSE)(UPP)>
CP_UPP<PROC_PTR, UPP, NEW, DISPOSE>::CP_UPP( PROC_PTR inUserRoutine )
	: fUPP(NEW( inUserRoutine ))
{
	CP_ThrowIfNULL( (void *) fUPP );
}

template <typename PROC_PTR, typename UPP, UPP (*NEW)(PROC_PTR), void (*DISPOSE)(UPP)>
CP_UPP<PROC_PTR, UPP, NEW, DISPOSE>::~CP_UPP() throw()
{
	DISPOSE(fUPP);
}

	// typedefed upps
typedef CP_UPP<EventHandlerProcPtr, EventHandlerUPP, NewEventHandlerUPP, DisposeEventHandlerUPP>			CP_EventHandlerUPP;
typedef CP_UPP<ControlActionProcPtr, ControlActionUPP, NewControlActionUPP, DisposeControlActionUPP>		CP_ControlActionUPP;

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_MAC

#endif	// _H_CP_UPPs

