//=========================================================================
//
//	FILE:				CP_IconControl.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms icon control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 27 $
//						Latest Checkout:  $Date: 2004-12-29 12:45:10 -0800 (Wed, 29 Dec 2004) $
//
//========================================================================
#ifndef _H_CP_IconControl
#define _H_CP_IconControl
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"
#include "CP_Structure_Defines.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_IconControl
*	@brief		Implementation of a platforms icon control.
*
*	@ingroup	UI
*/
class CP_EXPORT CP_IconControl : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_IconControl();
										CP_IconControl(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_S_ViewContentInfo& inContentInfo,
												UInt32 inCommand,
												bool inDontTrack = true );
	//! Destructor.
	virtual								~CP_IconControl() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}
			
	//! @name Setters
	//@{
			void						SetContent( const CP_S_ViewContentInfo& inContentInfo );
	//@}

protected:
	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

	// class data
protected:
	CP_S_ViewContentInfo				fContentInfo;			/*! Structure used to hold information about
																	the contents of the button. */
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												UInt32 inCommand,
												bool inDontTrack = true );
	//@}
#endif

#if TARGET_OS_WIN32
public:
	//! @name Events
	//@{
	virtual	void						HandleMouseDown( CP_Event_Base& inEvent );
	//@}

	//! @name Slots
	//@{
	virtual	void						HandleCommandProcess( CP_Event_Base& inEvent );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												UInt32 inCommand,
												bool inDontTrack = true );
	//@}
#endif

#if TARGET_OS_LINUX
public:
	//! @name Slots
	//@{
	virtual	void						HandleCommandProcess( CP_Event_Base& inEvent );
	//@}

	//! @name Events
	//@{
	virtual	void						HandleMouseDown( CP_Event_Base& inEvent );
	virtual	void						HandleMouseUp( CP_Event_Base& inEvent );
	//@}
	
protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												UInt32 inCommand,
												bool inDontTrack = true );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_IconControl
