//=========================================================================
//
//	FILE:				CP_PlatformControl.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_View class that serves as the base class for all
//						UI elements that are based on the OS platforms native
//						UI element.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 45 $
//						Latest Checkout:  $Date: 2005-01-03 23:14:36 -0800 (Mon, 03 Jan 2005) $
//
//=========================================================================
#ifndef _H_CP_PlatformControl
#define _H_CP_PlatformControl
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_CommandNos.h"
#include "CP_Event.h"
#include "CP_View.h"
#include "CP_SignalSlotHolder.h"
#include "CP_String.h"
#include "CP_Types.h"
#include "CP_View.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_PlatformControl
*	@brief		CP_View class that serves as the base class for all UI elements that are
*				based on the OS platforms native UI element.
*
*	@ingroup	UI
*/
class CP_EXPORT CP_PlatformControl : public CP_View
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_PlatformControl(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												const CP_String& inTitle,
												UInt32 inCommand = CP_CMD_NoCommand );
	//@}
	//! Destructor.
	virtual								~CP_PlatformControl() throw();
	//@}
			
	//! @name Getters
	//@{
			OSControl					GetOSControl();
	//@}

	//! @name Signal / Slots
	//@{
			void						SendValueChangedSignal( SInt32 inValue );
			
	virtual	void						HandleCommandProcess( CP_Event_Base& inEvent );
			void						SetValueSlot(
												CP_DataValueHolder& inValue,
												OSStatus& inOutStatus );
	//@}

	//! @name Setters
	//@{
										/*!
										*	Sets the commannd associated with this control.
										*	
										*	@param		inCommand			The commannd associated with this control.
										*	
										*	@exception	none
										*	
										*	@return		void
										*/
			void						SetCommand( UInt32 inCommand )				{ fCommand = inCommand; }
	virtual	void						SetFontSpec( CP_FontSpec& inFontSpec );
	//@}

	//! @name Title / text
	//@{
	virtual	void						SetTitle( const CP_String& inText );
	//@}

	//! @name Value
	//@{
	virtual	SInt32						GetValue();
	virtual	void						SetValue( SInt32 inValue );
			
	virtual	SInt32						GetMin();
	virtual	void						SetMin( SInt32 inValue );

	virtual	SInt32						GetMax();
	virtual	void						SetMax( SInt32 inValue );
	//@}
			
protected:
	//! @name Constructor / Destructor
	//@{
										CP_PlatformControl();
	//@}

	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}

	// class data
protected:
	UInt32								fCommand;				/*! The command sent when the control is clicked. */

		// Values
	SInt32								fValue;
	SInt32								fMinimum;
	SInt32								fMaximum;
		
		// Signals
	CP_DataValueSignal					fValueChangedSignal;	/*! Signal sent when the value changes. */
	CP_DataValueSignal					fClickedSignal;			/*! Signal sent when the control is clicked. */
	
		// slots
	CP_DataValueSlot					fSetValueSlot;

	#if TARGET_OS_WIN32
		CP_RGBColor						fForeColor;
		CP_RGBColor						fBackColor;
	#endif

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Control Data
	//@{
			void						GetControlDataTag(
												SInt16 inPartCode,
												FourCharCode inDataTag,
												Size inDataSize,
												void *inData,
												Size *outDataSize ) const;
			void						SetControlDataTag(
												SInt16 inPartCode,
												FourCharCode inDataTag,
												Size inDataSize,
												void *inData );
	//@}
#endif

#if TARGET_OS_WIN32
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_PlatformControl

