//=========================================================================
//
//	FILE:				CP_ProgressBar.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms progress bar control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_ProgressBar
#define _H_CP_ProgressBar
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_PlatformControl.h"

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_ProgressBar
*	@brief		Implementation of a platforms progress bar control.
*
*	@ingroup	UI
*/
class CP_EXPORT CP_ProgressBar : public CP_PlatformControl
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_ProgressBar();
										CP_ProgressBar(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												SInt32 inValue,
												SInt32 inMinimum,
												SInt32 inMaximum,
												bool isIndeterminate = false );
	//! Destructor.
	virtual								~CP_ProgressBar() throw();
	//@}
			
	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}
			
	//! @name Value
	//@{
	virtual	SInt32						GetValue();
	virtual	void						SetValue( SInt32 inValue );
			
			SInt32						GetMin();
			void						SetMin( SInt32 inValue );

			SInt32						GetMax();
			void						SetMax( SInt32 inValue );
	//@}

protected:
	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}

	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

	// class data
protected:
	
	#if TARGET_OS_LINUX
		GtkAdjustment					*fAdjustment;		/*! Contains the values displayed by the progress bar. */
	#endif
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												SInt32 inValue,
												SInt32 inMinimum,
												SInt32 inMaximum,
												bool isIndeterminate );
	//@}
#endif

#if TARGET_OS_WIN32
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												SInt32 inValue,
												SInt32 inMinimum,
												SInt32 inMaximum,
												bool isIndeterminate );
	//@}
#endif

#if TARGET_OS_LINUX
private:
	//! @name Initialization
	//@{
			void						CreatePlatformImp(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize,
												SInt32 inValue,
												SInt32 inMinimum,
												SInt32 inMaximum,
												bool isIndeterminate );
	//@}
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_ProgressBar
