//=========================================================================
//
//	FILE:				CP_QT_MovieView.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_View subclass to display a QuickTime Movie. 
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 276 $
//						Latest Checkout:  $Date: 2005-09-12 22:03:50 -0700 (Mon, 12 Sep 2005) $
//
//=========================================================================
#ifndef _H_CP_QT_MovieView
#define _H_CP_QT_MovieView
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_TimedTask.h"
#include "CP_View.h"

#if TARGET_OS_MAC
	#if TARGET_API_MAC_CARBON && __CF_USE_FRAMEWORK_INCLUDES__
		#include <QuickTime/Movies.h>
		#include <QuickTime/QuickTimeVR.h>
	#else
		#include <Movies.h>
		#include <QuickTimeVR.h>
	#endif
#endif

#if TARGET_OS_WIN32
	#if CP_Optional_QuickTime_Windows
		#include <Movies.h>
		#include <QuickTimeVR.h>
	#endif
#endif

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class		CP_QT_MovieView
*	@brief		CP_View subclass to display a QuickTime Movie.
*/
class CP_EXPORT CP_QT_MovieView : public CP_View
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_QT_MovieView();
										CP_QT_MovieView(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//! Destructor.
	virtual								~CP_QT_MovieView() throw();
	//@}
			
	//! @name Appearance
	//@{
	virtual	void						Show();
	virtual	void						Hide();

	virtual	void						Activate();
	virtual	void						Deactivate();

	virtual	void						Enable();
	virtual	void						Disable();
	//@}

	//! @name Drawing
	//@{
	virtual	CP_Canvas					SetupForDrawing();
	//@}

	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );

			void 						HandleControlHitEvent( CP_Event_Base& inEvent );
	//@}

	//! @name Movie
	//@{
			Movie						GetMovie()									{ return( fMovie ); }
			MovieController				GetMovieController()						{ return( fMovieController ); }
	//@}

	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}

	//! @name Setters
	//@{
			void						SetMovie(
												Movie inMovie,
												bool inSizeWindowToFit,
												SInt16 inScrollBarVerAdjustment = 0 );
	//@}

	//! @name Skins
	//@{
			void						SetIsSkinned( bool inIsSkinned )			{ fIsSkinned = inIsSkinned; }
	//@}

	//! @name Timer
	//@{
			void						StartIdleTimer();
			void						StopIdleTimer();

			bool						GetIdleOnInactiveWindow()					{ return( fIdleOnInactiveWindow ); }
			void						SetIdleOnInactiveWindow( bool inIdle );
	//@}

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

	//! @name Frame
	//@{
	virtual	void						OnBoundsChanged(
												const CP_Rect& inPreviousBounds,
												const CP_Rect& inNewBounds );
	//@}

	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}

	//! @name Timer
	//@{
	virtual	void						HandleIdleTime();
	//@}

private:
	//! @name Timer
	//@{
			void						TimerTask(
													CP_DataValueHolder& inDataValue,
													OSStatus& inOSStatus );
	//@}

	// class data
protected:
	CP_TimedTask						*fIdleTimer;
	
	Movie								fMovie;
	MovieController						fMovieController;
	
	bool								fIdleOnInactiveWindow;
	
	bool								fIsSkinned;
	
//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
#endif

#if TARGET_OS_WIN32
public:
	virtual	LRESULT						HandleWinProcMessage(
												HWND hwnd,
												UINT iMsg,
												WPARAM wParam,
												LPARAM lParam );
#endif

#if TARGET_OS_LINUX
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_QT_MovieView

