//=========================================================================
//
//	FILE:				CP_SelectColorButton.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Implementation of a platforms bevel button control.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 135 $
//						Latest Checkout:  $Date: 2005-04-03 13:52:42 -0700 (Sun, 03 Apr 2005) $
//
//=========================================================================
#ifndef _H_CP_SelectColorButton
#define _H_CP_SelectColorButton
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

	// CPLAT_Framework
#include "CP_View.h"

CPLAT_Begin_Namespace_CPLAT

class CP_EXPORT CP_SelectColorButton : public CP_View
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_SelectColorButton();
										CP_SelectColorButton(
												CP_View *inSuperview,
												const CP_Point& inUpperLeft,
												const CP_Size& inContentSize );
	//! Destructor.
	virtual								~CP_SelectColorButton() throw();
	//@}
			
			CP_RGBColor					GetColor()									{ return( fColor ); }
			void						SetColor( const CP_RGBColor& inColor );

	//! @name Persistance
	//@{
	static CP_M_Persist					*PersistCreator();
	//@}
			
			SInt32						GetValue()									{ return( fValue ); }
			void						SetValue( SInt32 inValue )					{ fValue = inValue; }

			UInt32						GetCommand()								{ return( fCommand ); }
			void						SetCommand( UInt32 inCommand )				{ fCommand = inCommand; }

protected:
	//! @name Drawing
	//@{
	virtual	void						OnDraw(
												CP_Canvas& inCanvas,
												CP_Region& inUpdateArea );
	//@}

	//! @name Events
	//@{
	virtual	void						InitEventHandler( CP_EventHandler& inEventHandler );
	//@}

	//! @name Persistance
	//@{
	virtual	void						OnInitPersist(
												CP_View *inSuperview,
												CP_DataValueList& inDataValueList );
	//@}


	// class data
protected:
	CP_RGBColor							fColor;
	SInt32								fValue;
	UInt32								fCommand;
	
		// Signals
	CP_DataValueSignal					fClickedSignal;			/*! Signal sent when the control is clicked. */

//========================================================================
// Platform specific routines
//========================================================================
#if TARGET_OS_MAC
public:
	//! @name Events
	//@{
	virtual	ControlPartCode				HandleHitTest( const CP_Point& inMouseLocation );
	virtual	ControlPartCode				HandleTracking(
												const CP_Point& inMouseLocation,
												ControlActionUPP actionProc );
	//@}
#endif

#if TARGET_OS_WIN32
private:
	virtual	void						HandleControlHitEvent( CPLAT::CP_Event_Base& inEvent );

	static UINT APIENTRY				CP_ChooseColorHook(
												HWND hWnd,
												UINT uMsg,
												WPARAM wParam,
												LPARAM lParam );
#endif

#if TARGET_OS_LINUX
public:
#endif
};

CPLAT_End_Namespace_CPLAT

#endif	// _H_CP_SelectColorButton
