//=========================================================================
//
//	FILE:				CP_Event_Imp_Win.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			CP_Event class implementation for a Windows event.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 2 $
//						Latest Checkout:  $Date: 2004-12-21 19:40:38 -0800 (Tue, 21 Dec 2004) $
//
//=========================================================================
#ifndef _H_CP_Event_Imp_Win
#define _H_CP_Event_Imp_Win
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_WIN32

	// CPLAT_Framework
#include "CP_NoCopy.h"
#include "CP_Point.h"
#include "CP_Types.h"

CPLAT_Begin_Namespace_CPLAT

//!  CP_Event_Imp
/*!
*	CP_Event class implementation for a Windows event. 
*/
class CP_EXPORT CP_Event_Imp : public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Event_Imp();
										CP_Event_Imp(
												UInt32 inClassID, 
												UInt32 inKind );
										CP_Event_Imp(
												HWND inWindow,
												WPARAM inWParam, 
												LPARAM inLParam );
	//! Destructor.
	virtual								~CP_Event_Imp();
	//@}
			
	//! @name Converters
	//@{
			void						ToWinMSG( MSG& msg );
			void						FromWinMSG( MSG& msg );
	//@}

	//! @name Getters
	//@{
			UInt32						GetWParam()											{ return( fParam1 ); }
			SInt32						GetLParam()											{ return( fParam2 ); }
			OSWindow					GetOSWindow()										{ return( fWindow ); }
	//@}
			
	//! @name Sending
	//@{
			void						Send( HWND inTarget );
	//@}

	//! @name Setters
	//@{
			void						SetWParam( UInt32 inWParam )						{ fParam1 = inWParam; }
			void						SetLParam( SInt32 inLParam )						{ fParam2 = inLParam; }
			void						SetOSWindow( OSWindow inWindow )					{ fWindow = inWindow; }
	//@}

protected:
	//! @name Misc - Utility
	//@{
			void						CopyImpFields( const CP_Event_Imp& inEventImp );
	//@}

	// class data
protected:
	UInt32								fMessage;		/*! Message for the event. */
	UInt32								fWhen;			/*! Time the event occurred at. */
	OSWindow							fWindow;		/*! Window the event occurred in */
	CP_Point							fWhere;			/*! Mouse location for this event. */
	UInt32								fParam1;		/*! wParam for this event. */
	SInt32								fParam2;		/*! lParam for this event. */
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_WIN32

#endif	// _H_CP_Event_Imp_Win

