//=========================================================================
//
//	FILE:				CP_FileSystemSpec_Imp_Win.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Windows implemention of the CP_FileSystemSpec class.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 106 $
//						Latest Checkout:  $Date: 2005-03-21 15:03:06 -0800 (Mon, 21 Mar 2005) $
//
//=========================================================================
#ifndef _H_CP_FileSystemSpec_Imp_Win
#define _H_CP_FileSystemSpec_Imp_Win
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_WIN32

	// CPLAT_Framework
#include "CP_String.h"

#if CP_Optional_QuickTime_Windows
	#include <Files.h>
#endif

CPLAT_Begin_Namespace_CPLAT

/*!
*	@class	CP_FileSystemSpec_Imp
*	@brief	Windows implementation of the CP_FileSystemSpec_Imp class.
*	
*			This class implements the CP_FileSystemSpec for the Windows platform,
*			and has methods you can call directly, or are called by the framework
*			for Windows specific features.
*/
class CP_EXPORT CP_FileSystemSpec_Imp
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Destructor.
	virtual								~CP_FileSystemSpec_Imp();
	//@}
			
	//! @name Getters
	//@{
			CP_String					GetName() const;
			CP_String					GetFullPath() const;
	#if CP_Optional_QuickTime_Windows
			FSSpec						GetFSSpec();
	#endif
	//@}

	//! @name Setters
	//@{
			void						Set( const CP_String& inFullpath );
			void						SetName( const CP_String& inFileName );
	//@}

	//! @name Testers
	//@{
										/*!
										*	Return true if this points to a valid file specification in the
										*	platforms native file system. The file can be valid, but not yet
										*	exist in the native file system.
										*	
										*	@return	bool const		True if the file specification is valid.
										*/
			bool						IsValid() const										{ return( fIsValid ); }

			bool						IsEqual( const CP_FileSystemSpec_Imp& inFileSpec_Imp ) const;

			bool						IsDirectory() const;
	//@}
			
protected:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_FileSystemSpec_Imp();
										CP_FileSystemSpec_Imp( const CP_FileSystemSpec_Imp& inFileSpec );
										CP_FileSystemSpec_Imp( const CP_String& inFullPath );
	#if CP_Optional_QuickTime_Windows
										CP_FileSystemSpec_Imp( const FSSpec& inFSSpec );
	#endif
	//@}

	//! @name operators
	//@{
			CP_FileSystemSpec_Imp&		operator = ( const CP_FileSystemSpec_Imp& );
	//@}

private:
	#if CP_Optional_QuickTime_Windows
		OSErr							FSSpecToFullPath(
												const FSSpec &inFSSpec,
												char *inOutPath );
		OSErr							GetFolderParent(
												const FSSpec *inFSSpec,
												FSSpec *inOutParent );
	#endif
	
	// class data
protected:
	bool								fIsValid;			/*! flag to indicate if this object holds a valid specification for a file,
																which may or may not currently exist in the file system. */

	CP_String							fFullPath;			/*! String containing the path of the file. */
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_WIN32

#endif	// _H_CP_FileSystemSpec_Imp_Win
