//=========================================================================
//
//	FILE:				CP_Menu_Imp_Win.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Windows implementation of the CP_Menu class.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 247 $
//						Latest Checkout:  $Date: 2005-07-30 19:06:38 -0700 (Sat, 30 Jul 2005) $
//
//=========================================================================
#ifndef _H_CP_Menu_Imp_Win
#define _H_CP_Menu_Imp_Win
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_WIN32

	// CPLAT_Framework
#include "CP_NoCopy.h"
#include "CP_String.h"

	// Standard Library
#include <vector>

CPLAT_Begin_Namespace_CPLAT

	// forward declarations
class CP_M_CommandHandler;

//=========================================================================
//	CP_CommandsNoArray
//=========================================================================
/*!
*	Standard library vector typedef to hold a list of CP_CommandNos for the menu
*	items in this menu. There is 1 item for each item in the menu.
*/
#ifndef TARGET_OS_LINUX
	typedef std::vector<CP_CommandNo, std::allocator<CP_CommandNo> >							CP_CommandsNo_Array;
	typedef std::vector<CP_CommandNo, std::allocator<CP_CommandNo> >::iterator					CP_CommandsNo_Iterator;
	typedef std::vector<CP_CommandNo, std::allocator<CP_CommandNo> >::reverse_iterator			CP_CommandsNo_ReverseIterator;
#else
	typedef std::vector<CP_CommandNo>															CP_CommandsNo_Array;
	typedef std::vector<CP_CommandNo>::iterator													CP_CommandsNo_Iterator;
	typedef std::vector<CP_CommandNo>::reverse_iterator											CP_CommandsNo_ReverseIterator;
#endif

/*!
*	@class		CP_Menu_Imp
*	@brief		Windows implementation of the CP_Menu class.
*/
class CP_EXPORT CP_Menu_Imp : public CP_NoCopy
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
										CP_Menu_Imp();
										CP_Menu_Imp(
												SInt16 inMenuID,
												const CP_String& inMenuTitle );
										CP_Menu_Imp( const CP_String& inMenuTitle );
										CP_Menu_Imp(
												SInt16 inMenuID,
												const CP_String& inMenuTitle,
												OSMenu inOSMenu );
	//! Destructor.
	virtual								~CP_Menu_Imp() throw();
	//@}
			
	//! @name Getters
	//@{
										/*!
										*	Return the Windows platform menu reference.
										*	
										*	@return	OSMenu		Windows menu reference.
										*/
			OSMenu						GetOSMenu()											{ return( fOSMenu ); }
			SInt16						GetMenuItemCount();
			CP_String					GetTitle() const;

										/*!
										*	Return the ID of this menu.
										*
										*	@exception	none
										*	
										*	@return		SInt16		ID of this menu.
										*/
			SInt16						GetID()												{ return( fMenuID ); }
			CP_CommandNo				GetCommand( SInt16 inItemIndex );
			SInt16						GetCommandItemIndex( const CP_CommandNo inCommand );
			CP_String					GetItemText( SInt16 inItemIndex );
	//@}
			
									// Menu Items
			void						AppendItem(
												const CP_String& inItemText,
												CP_CommandNo inCommand );
			void						DeleteItem( UInt16 inItemIndex );

			void						UpdateCommandStatus( CP_M_CommandHandler *inCommandHandler );

	//! @name Setters
	//@{
			void						SetTitle( const CP_String& inTitle );
	//@}

protected:
	//! @name Initialization
	//@{
			void						LoadOSMenu(
												SInt16 inMenuID,
												bool inPopup = false );
			void						LoadAsPopup( SInt16 inMenuID );
	//@}

private:
	//! @name Initialization
	//@{
			void						BuildCommandTable();
	//@}

	// class data
protected:
	SInt16								fMenuID;		/*! Menu id of this menu. */
	OSMenu								fOSMenu;		/*! Windows menu reference. */
	
	CP_CommandsNo_Array					*fCommands;		/*! Table of commands for each menu item. */

	CP_String							fMenuTitle;		/*! Title of the menu. */
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_WIN32

#endif	// _H_CP_Menu_Imp_Win

