//=========================================================================
//
//	FILE:				CP_WindowEvents.h
//	
//						Copyright  2004. Ken Stahlman. All Rights Reserved.
//	
//	PURPOSE:			Definition of common Windows events.
//	
//	HISTORY:			1st Version - August 2004.
//	
//	NOTES:				- none -
//
//	VERSION:			Current Revision: $Rev: 184 $
//						Latest Checkout:  $Date: 2005-05-20 20:14:15 -0700 (Fri, 20 May 2005) $
//
//=========================================================================
#ifndef _H_CP_WindowEvents
#define _H_CP_WindowEvents
#ifndef TARGET_OS_LINUX
	#pragma once
#endif

#if TARGET_OS_WIN32

	// CPLAT_Framework
#include "CP_Event.h"
#include "CP_Events_Defines.h"
#include "CP_Region.h"
#include "CP_TypeTraits.h"

	// Windows SDK
#include <windowsx.h>

CPLAT_Begin_Namespace_CPLAT

#if TARGET_CC_METROWERKS
#pragma mark === Commands ==
#endif

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_INITMENU> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	OSMenu						fMenu;			/*! The Windows HMENU that is opening. */
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_COMMAND> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	SInt16						fCommand;			/*! The command that is going to be handled. */
};

#if TARGET_CC_METROWERKS
#pragma mark === Events ==
#endif

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_CHAR> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	TCHAR						fCharCode;
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_HSCROLL> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	SInt16						fScrollbarPart;
	SInt16						fPosition;
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_VSCROLL> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	SInt16						fScrollbarPart;
	SInt16						fPosition;
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_SIZING> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	RECT						*fSizingRect;
};

template <>
class CP_Event<kCP_EventClassMouse, kCP_Event_MouseDown> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	CP_Point					fMouseLocation;			/*! The location of the mouse. */
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_MOUSEMOVE> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	CP_Point					fMouseLocation;			/*! The location of the mouse. */
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_MOUSELEAVE> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_LBUTTONDBLCLK> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	CP_Point					fMouseLocation;			/*! The location of the mouse. */
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_NOTIFY> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
};

#if TARGET_CC_METROWERKS
#pragma mark === Drawing ==
#endif

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_PAINT> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//! Destructor.
	virtual						~CP_Event();
	//@}
	
	// class data
public:
	HDC							fHDC;				/*! Windows graphics port for this event. */
	CP_Region					fUpdateRegion;		/*! update region for this event. */
	
private:
	PAINTSTRUCT					fPS;				/*! Windows paint structure supplied when the event was called. */
};
		
template <>
class CP_Event<kCP_WINDOW_EVENT, WM_DRAWITEM> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//! Destructor.
	virtual						~CP_Event();
	//@}
	
	// class data
public:
	LPDRAWITEMSTRUCT			fDrawItemStruct;
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_CTLCOLOREDIT> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
			void				ReturnInfo();
	
	// class data
public:
	HBRUSH						fBackgroundBrush;
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_ERASEBKGND> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
			void				ReturnInfo();
	
	// class data
public:
	HDC							fHDC;				/*! Windows graphics port for this event. */
	CP_Region					fUpdateRegion;		/*! update region for this event. */
	HBRUSH						fBackgroundBrush;
};

#if TARGET_CC_METROWERKS
#pragma mark === Misc ==
#endif

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_SIZE> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
	bool						fMinimized;			/*! Flag to indicate if the sending window is minimized. */
	SInt16						fNewWidth;			/*! New width for the window. */
	SInt16						fNewHeight;			/*! New height for the window. */
};

template <>
class CP_Event<kCP_WINDOW_EVENT, WM_TIMER> : public CP_Event_Base
{
public:
	//! @name Constructor / Destructor
	//@{
	//! Constructor.
								CP_Event( CP_Event_Base& inEvent );
	//@}
	
	// class data
public:
};

CPLAT_End_Namespace_CPLAT

#endif	// TARGET_OS_WIN32

#endif	// _H_CP_WindowEvents

